# Conditional for release and snapshot builds. Uncomment for release-builds.
%global rel_build 1

# This is needed, because src-url contains branched part of versioning-scheme.
%global branch 1.23

# Settings used for build from snapshots.
%{!?rel_build:%global commit c1ca209172a8b3a0751ac0a1e2dbec33c1894290}
%{!?rel_build:%global commit_date 20140712}
%{!?rel_build:%global shortcommit %(c=%{commit};echo ${c:0:7})}
%{!?rel_build:%global git_ver git%{commit_date}-%{shortcommit}}
%{!?rel_build:%global git_rel .git%{commit_date}.%{shortcommit}}
%{!?rel_build:%global git_tar %{name}-%{version}-%{git_ver}.tar.xz}

Summary:  Text editor for the MATE desktop
Name:     pluma
Version:  %{branch}.2
%if 0%{?rel_build}
Release:  1%{?dist}
%else
Release:  0.2%{?git_rel}%{?dist}
%endif
License:  GPLv2+ and LGPLv2+
URL:      http://mate-desktop.org

# for downloading the tarball use 'spectool -g -R pluma.spec'
# Source for release-builds.
%{?rel_build:Source0:     http://pub.mate-desktop.org/releases/%{branch}/%{name}-%{version}.tar.xz}
# Source for snapshot-builds.
%{!?rel_build:Source0:    http://git.mate-desktop.org/%{name}/snapshot/%{name}-%{commit}.tar.xz#/%{git_tar}}

BuildRequires: desktop-file-utils
BuildRequires: enchant2-devel
BuildRequires: libpeas-devel
BuildRequires: gtk3-devel
BuildRequires: gtksourceview3-devel
BuildRequires: iso-codes-devel
BuildRequires: libSM-devel
BuildRequires: mate-common
BuildRequires: pygobject3-devel
BuildRequires: python3-devel

Requires: %{name}-data = %{version}-%{release}
# needed to get a gsettings schema, #959607
Requires: mate-desktop-libs
# needed to get a gsettings schema, #959607
Requires: caja-schemas
# the run-command plugin uses zenity
Requires: zenity
# libpeas isn't splited in rhel7
#%%if 0%%{?fedora} && 0%%{?fedora} <= 28
Requires:      libpeas-loader-python
#%%endif

%description
pluma is a small, but powerful text editor designed specifically for
the MATE desktop. It has most standard text editor functions and fully
supports international text in Unicode. Advanced features include syntax
highlighting and automatic indentation of source code, printing and editing
of multiple documents in one window.

pluma is extensible through a plugin system, which currently includes
support for spell checking, comparing files, viewing CVS ChangeLogs, and
adjusting indentation levels.

%package data
Summary:   Data files for pluma
BuildArch: noarch
Requires:  %{name} = %{version}-%{release}

%description data
This package contains shared data needed for pluma.


%package devel
Summary:   Support for developing plugins for the pluma text editor
Requires:  %{name}%{?_isa} = %{version}-%{release}
Requires:  gtksourceview3-devel

%description devel
Development files for pluma


%prep
%if 0%{?rel_build}
%autosetup -p1
%else
%autosetup -n %{name}-%{commit} -p1
%endif

# with python3
sed -i 's|#!\/usr\/bin/\python|#!\/usr\/bin\/python3|g' plugins/externaltools/data/switch-c.tool.in

%if 0%{?rel_build}
# for releases
#NOCONFIGURE=1 ./autogen.sh
%else
# needed for git snapshots
NOCONFIGURE=1 ./autogen.sh
%endif

# Fix debug permissions with messy hack
find ./*/* -type f -exec chmod 644 {} \;
find ./*/*/* -type f -exec chmod 644 {} \;

%build
%configure \
        --disable-static          \
        --enable-gtk-doc-html     \
        --enable-gvfs-metadata    \
        --disable-schemas-compile

make %{?_smp_mflags} V=1

%install
%{make_install}

desktop-file-install                                \
    --delete-original                               \
    --dir %{buildroot}%{_datadir}/applications      \
%{buildroot}%{_datadir}/applications/*.desktop

# clean up all the static libs for plugins
find %{buildroot} -name '*.la' -exec rm -f {} ';'
find %{buildroot} -name '*.a' -exec rm -f {} ';'

%find_lang %{name} --with-gnome --all-name


%files
%{_bindir}/pluma
%{_libdir}/pluma/
%{_libexecdir}/pluma/
%{_libdir}/girepository-1.0/Pluma-1.0.typelib
%{_datadir}/applications/pluma.desktop
%{_datadir}/metainfo/pluma.appdata.xml
%{_datadir}/glib-2.0/schemas/org.mate.pluma.gschema.xml
%{_datadir}/glib-2.0/schemas/org.mate.pluma.plugins.filebrowser.gschema.xml
%{_datadir}/glib-2.0/schemas/org.mate.pluma.plugins.pythonconsole.gschema.xml
%{_datadir}/glib-2.0/schemas/org.mate.pluma.plugins.time.gschema.xml
%{_datadir}/glib-2.0/schemas/org.mate.pluma.plugins.spell.gschema.xml

%files data -f %{name}.lang
%doc README COPYING AUTHORS
%{_datadir}/pluma/
%{_mandir}/man1/pluma.1.*

%files devel
%{_includedir}/pluma/
%{_libdir}/pkgconfig/pluma.pc
%{_datadir}/gtk-doc/html/pluma/
%{_datadir}/gir-1.0/Pluma-1.0.gir


%changelog
* Sun Aug 18 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.23.2-1
- update to 1.23.2 

* Wed Jul 17 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.23.1-2
- test glib2 deprecation commit from master
- test https://github.com/mate-desktop/pluma/pull/484
- test https://github.com/mate-desktop/pluma/pull/485
- test https://github.com/mate-desktop/pluma/pull/482
- test https://github.com/mate-desktop/pluma/pull/488
- test https://github.com/mate-desktop/pluma/pull/489
- test https://github.com/mate-desktop/pluma/pull/494
- test https://github.com/mate-desktop/pluma/pull/491
- test https://github.com/mate-desktop/pluma/pull/490
- test https://github.com/mate-desktop/pluma/pull/492
- test https://github.com/mate-desktop/pluma/pull/493

* Wed Jul 17 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.23.1-1
- update to 1.23.1

* Mon Jun 03 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.23.0-2
- test https://github.com/mate-desktop/pluma/pull/390
- build with python3
- test https://github.com/mate-desktop/pluma/pull/412
- test https://github.com/mate-desktop/pluma/pull/443

* Mon Jun 03 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.23.0-1
- test 1.23.0
- enable python2 plugins again
- test https://github.com/mate-desktop/pluma/pull/433
- test https://github.com/mate-desktop/pluma/pull/434
- test https://github.com/mate-desktop/pluma/pull/435
- test https://github.com/mate-desktop/pluma/pull/436

* Fri Apr 26 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.22.1-1
- update to 1.22.1

* Mon Mar 04 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.22.0-2
- test https://github.com/mate-desktop/pluma/pull/397

* Mon Mar 04 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.22.0-1
- update to 1.22.0

* Sun Feb 11 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.21.2-4
- with https://github.com/mate-desktop/pluma/commit/eb0cc59
- with https://github.com/mate-desktop/pluma/commit/71daf90
- https://github.com/mate-desktop/pluma/pull/392
- test https://github.com/mate-desktop/pluma/commit/68fc438
- test https://github.com/mate-desktop/pluma/commit/f64c037
- test https://github.com/mate-desktop/pluma/commit/8e08ede
- test https://github.com/mate-desktop/pluma/pull/398
- test https://github.com/mate-desktop/pluma/pull/399
- test https://github.com/mate-desktop/pluma/pull/400
- test https://github.com/mate-desktop/pluma/pull/403
- test https://github.com/mate-desktop/pluma/pull/402
- test building against enchant2
- test https://github.com/mate-desktop/pluma/pull/404
- test https://github.com/mate-desktop/pluma/pull/405

* Sun Feb 11 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.21.2-3
- with https://github.com/mate-desktop/pluma/commit/eb0cc59
- with https://github.com/mate-desktop/pluma/commit/71daf90
- enable python plugins again for testing with f28
- https://github.com/mate-desktop/pluma/pull/392


* Sun Feb 11 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.21.2-2
- test https://github.com/mate-desktop/pluma/pull/384
- test https://github.com/mate-desktop/pluma/pull/385
- test https://github.com/mate-desktop/pluma/pull/388

* Sun Feb 11 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.21.2-1
- test 1.21.2

* Sun Feb 11 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.21.1-2
- test , cleanup build requires and requires
- test https://github.com/mate-desktop/eom/pull/174
- test https://github.com/mate-desktop/pluma/commit/e451bfe
- test https://github.com/mate-desktop/pluma/pull/343
- test https://github.com/mate-desktop/pluma/pull/346
- test https://github.com/mate-desktop/pluma/pull/345
- test https://github.com/mate-desktop/pluma/pull/350
- test https://github.com/mate-desktop/pluma/pull/353
- test https://github.com/mate-desktop/pluma/pull/352
- use https://github.com/mate-desktop/pluma/commit/957fc58
- test https://github.com/mate-desktop/pluma/pull/357
- test https://github.com/mate-desktop/pluma/pull/354
- test https://github.com/mate-desktop/pluma/pull/358
- test https://github.com/mate-desktop/pluma/pull/359
- test https://github.com/mate-desktop/pluma/pull/362
- local patch test

* Sun Feb 11 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.21.1-1
- test 1.21.1

* Sun Feb 11 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.21.0-2
- test https://github.com/mate-desktop/pluma/pull/302
- test https://github.com/mate-desktop/pluma/pull/303
- test https://github.com/mate-desktop/pluma/pull/304
- test https://github.com/mate-desktop/pluma/pull/306
- test https://github.com/mate-desktop/pluma/pull/308
- test https://github.com/mate-desktop/pluma/pull/309
- test https://github.com/mate-desktop/pluma/pull/311
- test https://github.com/mate-desktop/pluma/pull/314
- test https://github.com/mate-desktop/pluma/commit/310bfc2
- test https://github.com/mate-desktop/pluma/pull/316
- test https://github.com/mate-desktop/pluma/pull/317
- test https://github.com/mate-desktop/pluma/pull/318
- test https://github.com/mate-desktop/pluma/pull/319
- test https://github.com/mate-desktop/pluma/pull/320
- test https://github.com/mate-desktop/pluma/pull/324
- use https://github.com/mate-desktop/pluma/commit/8b793f4
- use https://github.com/mate-desktop/pluma/commit/28de7bc
- use https://github.com/mate-desktop/pluma/commit/72edb5d
- test https://github.com/mate-desktop/pluma/pull/328
- test https://github.com/mate-desktop/pluma/pull/330
- test https://github.com/mate-desktop/pluma/commit/3742ba4
- test https://github.com/mate-desktop/pluma/pull/334

* Sun Feb 11 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.21.0-1
- test 1.20.1
- drop IconCache rpm scriptlet

* Sun Feb 11 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.20.0-2
- test https://github.com/mate-desktop/pluma/pull/276
- test https://github.com/mate-desktop/pluma/pull/273
- test https://github.com/mate-desktop/pluma/pull/278
- test https://github.com/mate-desktop/pluma/pull/281
- test https://github.com/mate-desktop/pluma/pull/284
- test https://github.com/mate-desktop/pluma/pull/285
- test https://github.com/mate-desktop/pluma/pull/286
- test https://github.com/mate-desktop/pluma/pull/291
- test https://github.com/mate-desktop/pluma/pull/292
- test https://github.com/mate-desktop/pluma/pull/293
- test https://github.com/mate-desktop/pluma/pull/300

* Sun Feb 11 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.20.0-1
- update to 1.20.0 release
- drop desktop-database rpm scriptlet
- drop GSettings Schema rpm scriptlet
- switch to using autosetup

* Mon Jan 01 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.3-2
- test https://github.com/mate-desktop/pluma/pull/270

* Mon Jan 01 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.3-1
- update to 1.19.3
- test https://github.com/mate-desktop/pluma/pull/270

* Tue Jun 13 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.19.2-2
- test https://github.com/mate-desktop/pluma/pull/251
- test https://github.com/mate-desktop/pluma/pull/253
- test https://github.com/mate-desktop/pluma/pull/257
- test https://github.com/mate-desktop/pluma/pull/258
- test https://github.com/mate-desktop/pluma/pull/260
- test https://github.com/mate-desktop/pluma/pull/262
- test https://github.com/mate-desktop/pluma/pull/263
- test https://github.com/mate-desktop/pluma/pull/265
- re-test https://github.com/mate-desktop/pluma/commit/a154544

* Tue Jun 13 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.19.2-1
- test 1.19.2

* Tue Jun 13 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.19.1-2
- test https://github.com/mate-desktop/pluma/pull/235
- test https://github.com/mate-desktop/pluma/pull/236
- test https://github.com/mate-desktop/pluma/pull/237
- test deprecated gtk_show_uri fixes
- test https://github.com/mate-desktop/pluma/pull/241
- test https://github.com/mate-desktop/pluma/pull/245
- test https://github.com/mate-desktop/pluma/pull/243
- test https://github.com/mate-desktop/pluma/pull/247

* Tue Jun 13 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.19.1-1
- test update to 1.19.1

* Fri May 12 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.19.0-2
- test deprecation fixes

* Fri May 12 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.19.0-1
- update to 1.19.0

* Sat May 06 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.18.2-1
- update to 1.18.2
- use bookmarks dir
- test https://github.com/mate-desktop/pluma/pull/223

* Tue Apr 04 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.18.1-2
- test bookmarks dir
- test https://github.com/mate-desktop/pluma/pull/223

* Tue Apr 04 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.18.1-1
- test 1.18.1

* Tue Mar 28 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.18.0-2
- use https://github.com/mate-desktop/pluma/commit/910aec0
- test wayland fix

* Tue Mar 14 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.18.0-1
- update to 1.18.0 release

* Fri Mar 10 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.4-1
- update to 1.17.4 release
- test https://github.com/mate-desktop/pluma/pull/214
- test https://github.com/mate-desktop/pluma/pull/216

* Wed Feb 08 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.3-2
- use BR libpeas-loader-python only for fedora

* Mon Jan 09 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.3-1
- update to 1.17.3
- fix rhbz (#1411052)
- add BR libpeas-loader-python

* Sun Dec 25 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.2-1
- update to 1.17.2 release

* Thu Nov 17 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.0-1
- update to 1.17.0 release

* Wed Sep 21 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.16.0-1
- update to 1.16.0 release

* Thu Jun 09 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.15.2-1
- test 1.15.2

* Thu Jun 09 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.15.1-2
- test https://github.com/mate-desktop/pluma/pull/191

* Thu Jun 09 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.15.1-1
- update to 1.15.1 release

* Thu Jun 09 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.15.0-1
- update to 1.15.0 release

* Tue Apr 05 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.14.0-1
- update to 1.14.0 release

* Mon Feb 22 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.13.1-1
- update to 1.13.1 release

* Sun Feb 07 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.13.0-1
- update to 1.13.0 release

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.12.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Dec 04 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.12.1-1
- update to 1.12.1 release

* Sat Nov 21 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.12.0-2
- build with gtk3
- disable python plugins for the moment

* Fri Nov 06 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.12.0-1
- update to 1.12.0 release

* Thu Oct 22 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.11.0-1
- update to 1.11.0 release

* Tue Jul 14 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.2.1
- update to 1.10.2 release

* Thu Jul 02 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.1-2
- version bump to fix f21 build

* Thu Jun 18 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.1-1
- update to 1.10.1 release
- remove upstreamed patches

* Thu May 07 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.0-2
- fix translations in gsettings
- fix size of statusbar (gtk3)

* Thu May 07 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.0-1
- update to 1.10.0 release
- add patch to fix f23 build

* Mon Apr 06 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.90-1
- update to 1.9.90 release

* Thu Jan 22 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.1-1
- update to 1.9.1 release

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.9.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Tue Jul 15 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.0-1
- update to 1.9.0 release
- enable gtk-docs for release build
- disable autogen for release build

* Sat Jul 12 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.0-0.1.git20131511.c1ca209
- use git snapshot from 2014.07.12
- disable gtk-docs for snapshot build

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun May 04 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.8.1.1
- update to 1.8.1 release

* Wed Mar 05 2014 Dan Mashal <dan.mashal@fedoraproject.org> - 1.8.0-1
- Update to 1.8.0

* Wed Feb 19 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.7.90-1
- update to 1.7.90
- remove obsolete mate-text-editor binary from spec file

* Thu Feb 13 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.7.2-1
- update to 1.7.2 release
- fix rpmlint warning 'can't find source0'
- fix license information
- use a joker for the man file attribute
- move data in a noarch subpackage
- improve obsoletes
- update rpm scriplets

* Wed Dec 25 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.7.1-1
- update to 1.7.1 release
- add gtk-doc dir to -devel subpackage for release builds

* Wed Dec 25 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.7.1-0.1.git20131511.7ceb8fe
- rename to pluma
- make maintainers life easier and use better git snapshot usage, thanks to Björn Esser
- simplify remove of static libaries
- use modern 'make install' macro
- add --with-gnome flag to find_language, needed for yelp
- sort file section

* Fri Dec 06 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.7.0-1
- Update to 1.7.0

* Thu Aug 08 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.0-5
- add runtime require mate-file-manager-schemas to fix #959607

* Thu Aug 08 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.0-4
- switch to runtime require mate-desktop-libs
- remove needless --with-gnome flag in find_language

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Jun 30 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.0-2
- add runtime require mate-desktop, fix rhbz #959607
- remove pluma.convert files
- cleanup BR's
- fix desktop file install command, no needed to add X-MATE
- use runtime require mate-dialogs instead of zenity
- remove BR mate-conf-devel
- add --disable-static configure flag
- general usage of %%{buildroot}
- no need of mimeinfo rpm scriptlets
- fix desktop-database rpm scriptlets
- update BR's
- add isa tag to -devel subpackage

* Sat Apr 13 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.6.0-1
- Update to latest 1.6.0 stable release.

* Sun Feb 10 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.5.1-1
- Update to latest upstream release

* Mon Oct 15 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.4.0-2
- Fix build requires

* Sun Oct 14 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.4.0-1
- Initial build

